==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/survival/PassiveTemperatureEffects.java <==
package com.github.thedeathlycow.frostiful.survival;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.block.SunLichenBlock;
import com.github.thedeathlycow.frostiful.config.FrostifulConfig;
import com.github.thedeathlycow.frostiful.entity.component.SnowAccumulationComponent;
import com.github.thedeathlycow.frostiful.registry.tag.FBlockTags;
import com.github.thedeathlycow.frostiful.registry.tag.FEnchantmentTags;
import com.github.thedeathlycow.thermoo.api.temperature.event.EnvironmentTickContext;
import com.github.thedeathlycow.thermoo.api.temperature.event.LivingEntityTemperatureTickEvents;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_1944;
import net.minecraft.class_2338;
import net.minecraft.class_2680;

public final class PassiveTemperatureEffects {
    public static void initialize() {
        LivingEntityTemperatureTickEvents.GET_PASSIVE_TEMPERATURE_CHANGE.register(PassiveTemperatureEffects::getPassiveChange);
    }

    private static int getPassiveChange(EnvironmentTickContext<? extends class_1309> context) {
        class_1309 entity = context.affected();

        // don't touch scorchful's effects
        if (entity.method_7325() || entity.thermoo$getTemperature() > 0) {
            return 0;
        }

        int total = 0;

        FrostifulConfig config = Frostiful.getConfig();
        total += getHotFloorTemperatureChange(context, config);
        total += getAndUpdateBlockLightTemperatureChange(context);

        return total;
    }

    private static int getHotFloorTemperatureChange(EnvironmentTickContext<? extends class_1309> context, FrostifulConfig config) {
        class_1309 entity = context.affected();
        class_2680 steppingState = entity.method_25936();

        if (steppingState.method_26164(FBlockTags.HOT_FLOOR)) {
            class_1799 footStack = entity.method_6118(class_1304.field_6166);

            if (!class_1890.method_60138(footStack, FEnchantmentTags.IS_FROSTY)) {
                // TODO: fix fire particles
                SunLichenBlock.createFireParticles(context.world(), entity.method_24515());
                return config.freezingConfig.getHeatFromHotFloor();
            }
        }

        return 0;
    }

    private static int getAndUpdateBlockLightTemperatureChange(EnvironmentTickContext<? extends class_1309> context) {
        int warmthFromLight = getBlockLightTemperatureChange(context.world(), context.pos());
        if (warmthFromLight > 0) {
            SnowAccumulationComponent.get(context.affected()).meltSnowAccumulation();
        }

        return warmthFromLight;
    }

    /**
     * Gets the temperature change from block light in the surrounding area. Exposed as public for the location_warmth
     * loot condition.
     */
    public static int getBlockLightTemperatureChange(class_1937 world, class_2338 pos) {
        FrostifulConfig config = Frostiful.getConfig();

        int lightLevel = world.method_8314(class_1944.field_9282, pos);
        int minLightLevel = config.environmentConfig.getMinLightForWarmth();

        int warmth = 0;
        if (lightLevel >= minLightLevel) {
            warmth = config.environmentConfig.getWarmthPerLightLevel() * (lightLevel - minLightLevel);
        }

        return warmth;
    }

    private PassiveTemperatureEffects() {

    }
}

==> frostiful-2.2.9%2B1.21.9-sources.jar: com/github/thedeathlycow/frostiful/survival/PassiveTemperatureEffects.java <==
package com.github.thedeathlycow.frostiful.survival;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.config.FrostifulConfig;
import com.github.thedeathlycow.frostiful.entity.component.SnowAccumulationComponent;
import com.github.thedeathlycow.frostiful.registry.tag.FBlockTags;
import com.github.thedeathlycow.frostiful.registry.tag.FEnchantmentTags;
import com.github.thedeathlycow.thermoo.api.temperature.event.EnvironmentTickContext;
import com.github.thedeathlycow.thermoo.api.temperature.event.LivingEntityTemperatureTickEvents;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_1944;
import net.minecraft.class_2338;
import net.minecraft.class_2398;
import net.minecraft.class_2680;

public final class PassiveTemperatureEffects {
    public static void initialize() {
        LivingEntityTemperatureTickEvents.GET_PASSIVE_TEMPERATURE_CHANGE.register(PassiveTemperatureEffects::getPassiveChange);
    }

    private static int getPassiveChange(EnvironmentTickContext<? extends class_1309> context) {
        class_1309 entity = context.affected();

        // don't touch scorchful's effects
        if (entity.method_7325() || entity.thermoo$getTemperature() > 0) {
            return 0;
        }

        int total = 0;

        FrostifulConfig config = Frostiful.getConfig();
        total += getHotFloorTemperatureChange(context, config);
        total += getAndUpdateBlockLightTemperatureChange(context);

        return total;
    }

    private static int getHotFloorTemperatureChange(EnvironmentTickContext<? extends class_1309> context, FrostifulConfig config) {
        class_1309 entity = context.affected();
        class_2680 steppingState = entity.method_25936();
        class_1799 footStack = entity.method_6118(class_1304.field_6166);

        boolean applyHeat = steppingState.method_26164(FBlockTags.HOT_FLOOR)
                && !class_1890.method_60138(footStack, FEnchantmentTags.IS_FROSTY);

        if (applyHeat) {
            if (entity.method_59922().method_43048(10) == 0) {
                context.world().method_65096(
                        class_2398.field_11240,
                        entity.method_23317(),
                        entity.method_23318() + 0.3,
                        entity.method_23321(),
                        2,
                        0.2, 0.7, 0.2,
                        1e-2
                );
                return config.freezingConfig.getHeatFromHotFloor();
            } else {
                return config.freezingConfig.getHeatFromHotFloor() / 10;
            }
        }

        return 0;
    }

    private static int getAndUpdateBlockLightTemperatureChange(EnvironmentTickContext<? extends class_1309> context) {
        int warmthFromLight = getBlockLightTemperatureChange(context.world(), context.pos());
        if (warmthFromLight > 0) {
            SnowAccumulationComponent.get(context.affected()).meltSnowAccumulation();
        }

        return warmthFromLight;
    }

    /**
     * Gets the temperature change from block light in the surrounding area. Exposed as public for the location_warmth
     * loot condition.
     */
    public static int getBlockLightTemperatureChange(class_1937 world, class_2338 pos) {
        FrostifulConfig config = Frostiful.getConfig();

        int lightLevel = world.method_8314(class_1944.field_9282, pos);
        int minLightLevel = config.environmentConfig.getMinLightForWarmth();

        int warmth = 0;
        if (lightLevel >= minLightLevel) {
            warmth = config.environmentConfig.getWarmthPerLightLevel() * (lightLevel - minLightLevel);
        }

        return warmth;
    }

    private PassiveTemperatureEffects() {

    }
}
